Documentation
¶
Index ¶
Constants ¶
const ( ESCAPE = 92 QUOTE = 34 SPACE = 32 TAB = 9 NEWLINE = 10 ASTERISK = 42 SLASH = 47 HASH = 35 )
Variables ¶
This section is empty.
Functions ¶
func ReadFromFile ¶
ReadFromFile reads jsonc file and returns JSONC and JSON encodings
func Unmarshal ¶
Unmarshal parses the JSONC-encoded data and stores the result in the value pointed to by v. Equivalent of calling `json.Unmarshal(jsonc.ToJSON(data), v)`
func UnmarshalLenient ¶ added in v1.0.4
UnmarshalLenient parses JSONC (JSON with comments) into v, stripping comments and decoding only the first valid JSON value. This uses a json.NewDecoder which ignores trailing data, it will only read the first valid JSON value. Equivalent of calling `json.NewDecoder(bytes.NewReader(jsonc.ToJSON(data))).Decode(v)`
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.